diff --git a/.gitlab-ci.yml b/.gitlab-ci.yml
index a17700eacbba6aff36049c6113084b9cc78819d8..a9c760e1e72739d4d126e3f4d76013217cedf838 100644
--- a/.gitlab-ci.yml
+++ b/.gitlab-ci.yml
@@ -311,7 +311,7 @@ create-vps:
 # Stage: setup-cluster
 # ====================
 #
-# Installs OAS
+# Installs Stackspin
 
 test-dns:
   stage: setup-cluster
diff --git a/.gitlab/issue_templates/feedback.md b/.gitlab/issue_templates/feedback.md
index 4e15a5fcaf83528efa1992ba3ed77a2fef01188e..8822a479650d21e151f99d4170715353fda117ed 100644
--- a/.gitlab/issue_templates/feedback.md
+++ b/.gitlab/issue_templates/feedback.md
@@ -1,4 +1,4 @@
-This feedback template can be used to provide feedback based on the [OAS testing instructions](https://docs.stackspin.net/en/latest/testing_instructions.html).
+This feedback template can be used to provide feedback based on the [Stackspin testing instructions](https://docs.stackspin.net/en/latest/testing_instructions.html).
 
 # Installation
 
diff --git a/README.md b/README.md
index ba4c761713e7917c60cfb0388c5ceccb537d0994..f54335b36fca34bd46d659bc9159e6fee130a3c2 100644
--- a/README.md
+++ b/README.md
@@ -4,7 +4,7 @@ Stackspin allows you to easily set up a new Stackspin instance, based on
 a single-node kubernetes cluster.
 
 > **WARNING: The installation process will make substantial changes to the
-> server’s configuration, so please ONLY install OAS on a dedicated, clean
+> server’s configuration, so please ONLY install Stackspin on a dedicated, clean
 > server.**
 
 Please refer to https://docs.stackspin.net for further details,
diff --git a/docs/customizing.rst b/docs/customizing.rst
index 80f02df7b4781b6b964a7c88e91ba65a5b66e95f..92920f5958db8b7ee6bae0d59f95053bad2c5f98 100644
--- a/docs/customizing.rst
+++ b/docs/customizing.rst
@@ -4,26 +4,26 @@ Customizing
 
 In this guide we show how to customize your cluster installation, i.e. if you
 want to install additional applications, or change the configuration of extisting
-apps installed by OAS this is the right place. Customizing other parts of your
+apps installed by Stackspin this is the right place. Customizing other parts of your
 cluster is possible but not yet covered by this guide.
 This guide is written for users with advanced knowledge of the tools behind
 Stackspin, most importantly: Kubernetes, Helm, Ansible and Flux 2.
 
 .. warning::
 
-  Customizing your OAS cluster could break your cluster in a way that it's not
+  Customizing your Stackspin cluster could break your cluster in a way that it's not
   easy to recover. Please be aware of the potential risk when proceeding.
 
 Prerequisites
 =============
 
-* A functional OAS cluster installed following the
+* A functional Stackspin cluster installed following the
   `Stackspin installation instructions <installation_instructions.html>`__
 
-Customize OAS applications
+Customize Stackspin applications
 ==========================
 
-Apps deployed by OAS are configured using helm values from templates in
+Apps deployed by Stackspin are configured using helm values from templates in
 ``flux2/apps/<application>/release.yaml``. It is possible to override values
 from the helmrelease by adding a custom ``ConfigMap`` or ``Secret`` to the
 cluster. The secret or configmap name is specified in the ``valuesFrom`` section
diff --git a/docs/design.md b/docs/design.md
index f269aa08a65f50975532d3c72e5fa46c6bbbd405..9d5739043005db6e99108261b275fcb9e22ca7c2 100644
--- a/docs/design.md
+++ b/docs/design.md
@@ -101,10 +101,10 @@ Stackspin clusters will be developed by us.
 Containerised applications are normally "stateless" (meaning no data is saved
 inside the containers). However, it is possible to mount persistent volumes to
 specific directories in the container, basically adding a persistent layer on
-top of the containerised application. To provide this in OAS's simple setup, we
+top of the containerised application. To provide this in Stackspin's simple setup, we
 use a [local storage
 provisioner](https://open.greenhost.net/stackspin/local-path-provisioner)
-that automatically provides persistent data on the VPS running OAS to an
+that automatically provides persistent data on the VPS running Stackspin to an
 application that requests it.
 
 ## Automatic updates
diff --git a/docs/index.rst b/docs/index.rst
index c7078f255a08e907bf2ce24b94a434305a2246a4..fe6d38116522326477fd536737b7293f85148c17 100644
--- a/docs/index.rst
+++ b/docs/index.rst
@@ -6,7 +6,7 @@
 Welcome to Stackspin's documentation!
 ========================================
 
-Stackspin (OAS) is a platform that will offer self-managed, click-and-play
+Stackspin (Stackspin) is a platform that will offer self-managed, click-and-play
 provisioning of online applications for Civil Society Organisations (CSOs).
 Users will be able to easily set up a self-hosted instance of Stackspin, so
 they can keep control over the data that gets entered into these applications.
diff --git a/docs/security.rst b/docs/security.rst
index 29711b3fd49444e8c3aedf894ba5ad0991b65330..5b1222dc8766493de094f080f7b25a64248fccf5 100644
--- a/docs/security.rst
+++ b/docs/security.rst
@@ -5,14 +5,14 @@ Security
 Access control
 ==============
 
-By default, the applications on your OAS cluster will be exposed to the whole
+By default, the applications on your Stackspin cluster will be exposed to the whole
 internet (although they are password protected).
 
 If you like to limit who can access your cluster resources you can configure
-the OAS ingress (`ingress-nginx <https://kubernetes.github.io/ingress-nginx>`__)
+the Stackspin ingress (`ingress-nginx <https://kubernetes.github.io/ingress-nginx>`__)
 to only accept connections from a certain IP address or range.
 
-Follow the :ref:`customizing:Customize OAS applications` instructions, but use the following
+Follow the :ref:`customizing:Customize Stackspin applications` instructions, but use the following
 secret as ``install/overrides/stackspin-nginx-override.yml`` and apply the secret in
 the ``stackspin`` namespace instead of ``stackspin-apps``. Replace the source range with the
 IP address ranges you want to allow.
diff --git a/docs/testing.rst b/docs/testing.rst
index bb45008ec00bdb9c712e0e6e3194df1ba627f6f8..5611b274e78d653493f6b11fdcdac7678810e787 100644
--- a/docs/testing.rst
+++ b/docs/testing.rst
@@ -14,7 +14,7 @@ instructions <#providing-feedback>`__.
 During these instructions, please replace *example.org* with your own
 domain name.
 
-OAS installation
+Stackspin installation
 ----------------
 
 First we’d like you to setup an Stackspin cluster by yourself,
@@ -36,7 +36,7 @@ Please login using single sign-on as ``admin`` and see if you have admin
 rights granted (usually there’s an app specific admin panel available or
 admin functionality like configuring users). Afterwards logout and login
 again as the non-admin single-sign-on user you created earlier in the
-OAS admin panel. You should *not* have any admin privileges now.
+Stackspin admin panel. You should *not* have any admin privileges now.
 
 Testing Instructions for specific apps
 --------------------------------------
diff --git a/docs/troubleshooting.rst b/docs/troubleshooting.rst
index 3d629314acd9005d8e23cccbb616aeefda5fae8d..b7b9c2870b69e39afcd2bf123e31d490c07168d8 100644
--- a/docs/troubleshooting.rst
+++ b/docs/troubleshooting.rst
@@ -6,7 +6,7 @@ problem. This document describes what you can do.
 
 .. note::
    ``cluster$`` indicates that the commands should be run as root on your
-   OAS machine.
+   Stackspin machine.
 
 **We would love to hear from you!** If you have problems, please create an issue
 in our `issue tracker
@@ -38,9 +38,9 @@ Testinfra tests
 
 Testinfra tests are split into two groups, lets call them *blackbox* and
 *clearbox* tests.  The blackbox tests run on your provisioning machine and test
-the OAS cluster from the outside. For example, the certificate check will check
-if the OAS returns valid certificates for the provided services.
-The clearbox tests run on the OAS host and check i.e. if docker is installed
+the Stackspin cluster from the outside. For example, the certificate check will check
+if the Stackspin returns valid certificates for the provided services.
+The clearbox tests run on the Stackspin host and check i.e. if docker is installed
 in the right version etc. Our testinfra tests are a combination of blackbox and
 clearbox tests.
 
@@ -229,7 +229,7 @@ Using kubectl to debug your cluster
 
 You can use ``kubectl``, the Kubernetes control program, to find and manipulate
 your Kubernetes cluster. Once you have installed ``kubectl``, to get access to
-your cluster with the OAS CLI:
+your cluster with the Stackspin CLI:
 
 .. code:: bash
 
@@ -248,7 +248,7 @@ window*, ``kubectl`` will connect to your cluster.
 HTTPS Certificates
 ------------------
 
-OAS uses `cert-manager <https://docs.cert-manager.io/en/latest/>`__ to
+Stackspin uses `cert-manager <https://docs.cert-manager.io/en/latest/>`__ to
 automatically fetch `Let's Encrypt <https://letsencrypt.org/>`__ certificates
 for all deployed services. If you experience invalid SSL certificates, i.e. your
 browser warns you when visiting Rocketchat (https://chat.stackspin.example.org),
@@ -422,11 +422,11 @@ running ``flux reconcile kustomization kube-prometheus-stack`` (replace
 ``kube-prometheus-stack`` with the kustomization is mentioned in the error
 message).
 
-Purge OAS and install from scratch
+Purge Stackspin and install from scratch
 ----------------------------------
 
 If ever things fail beyond possible recovery, here's how to completely purge an
-OAS installation in order to start from scratch:
+Stackspin installation in order to start from scratch:
 
 .. warning::
 
diff --git a/docs/usage.rst b/docs/usage.rst
index f7e234e5b63f982e802f6a0fa1010e3fa22248ae..81e6f459d759a541827af5e7e7d4cb9b57701360 100644
--- a/docs/usage.rst
+++ b/docs/usage.rst
@@ -1,7 +1,7 @@
 Usage
 =====
 
-OAS User panel
+Stackspin User panel
 --------------
 
 After all the applications are installed, the first thing to do is log into
diff --git a/flux2/README.md b/flux2/README.md
index 870e2a07ce337a0bbc30ab4b7aec051938b6704b..8168e9b3c9c783dbdfdd5d2f08dfee6358a5581d 100644
--- a/flux2/README.md
+++ b/flux2/README.md
@@ -28,10 +28,10 @@ flux2
 │       ├── cluster-issuer # `cert-manager` is part of `infrastructure`, this only adds the cluster-issuer
 │       ├── metallb        # Load balancer
 │       └── single-sign-on # Single sign-on system
-└── infrastructure  # First to be installed, essential OAS resources
+└── infrastructure  # First to be installed, essential Stackspin resources
     ├── cert-manager           # Let's Encrypt certificate generator
     ├── local-path-provisioner # (default) storage class to safe files on disk
-    ├── namespaces             # namespaces used by OAS
+    ├── namespaces             # namespaces used by Stackspin
     ├── nginx    # Ingress
     └── sources  # Helm repositories needed for HelmReleases from other folders
 ```
diff --git a/openappstack/cluster.py b/openappstack/cluster.py
index a43ff19cdd1ee5a64acf92b53edca60efbf0b636..bc1dc353fd807a5a338ffb60f40213816dcb515c 100644
--- a/openappstack/cluster.py
+++ b/openappstack/cluster.py
@@ -94,7 +94,7 @@ class Cluster:
 
     def create_droplet(self, ssh_key_id=0, hostname=None):
         """
-        Uses the Cosmos API to create a droplet with OAS default spec
+        Uses the Cosmos API to create a droplet with Stackspin default spec
 
         :param int ssh_key_id: SSH key ID in Greenhost Cosmos.
         :param str hostname: hostname of the droplet created at GH. Defaults to
@@ -195,7 +195,7 @@ KUBECONFIG={cluster_dir}/kube_config_cluster.yml
 
     def dump_secrets(self):
         """
-        Shows all OAS cluster secrets.
+        Shows all Stackspin cluster secrets.
         """
         all_secrets = {
             'flux-system': {
diff --git a/test/taiko/single-sign-on.js b/test/taiko/single-sign-on.js
index 0d1ab1f228d58593466c347058cdcb7738a8deaf..ca7fc5ea685436a04869ea03d64be82cf56550ca 100644
--- a/test/taiko/single-sign-on.js
+++ b/test/taiko/single-sign-on.js
@@ -26,7 +26,7 @@ const assert = require('assert');
 
     await goto(adminpanelUrl)
     await click('Login')
-    await click('Login with OAS')
+    await click('Login with Stackspin')
     await write(username, into(textBox('Username')))
     await write(pw, into(textBox('Password')))
     await click('Remember me')
diff --git a/openappstack/__main__.py b/openappstack/__main__.py
index 422b921ff95af1154fd8f2cd7adb7227c54d8fc8..fb5935dc1e46418b519d5447c6e837951a28c813 100755
--- a/openappstack/__main__.py
+++ b/openappstack/__main__.py
@@ -205,7 +205,7 @@ def main():  # pylint: disable=too-many-statements,too-many-branches,too-many-lo
 
     secrets_parser = subparsers.add_parser(
         'secrets',
-        help=("Show OAS cluster secrets"))
+        help=("Show Stackspin cluster secrets"))
     secrets_parser.set_defaults(func=secrets)
 
     args = parser.parse_args()
@@ -344,7 +344,7 @@ def install(clus, args):
     """
     Parses arguments for the 'install' subcommand
 
     :param cluster.Cluster clus: Cluster object to install OAS to
     :param argparse.Namespace args: Command line arguments
     """
     clus.load_data()
@@ -446,7 +446,7 @@ def create_domain_records(domain, droplet_ip, subdomain=None):
 
     :param str domain: the domain the cluster will be hosted on.
     :param str droplet_ip: The IP address the A record will point to.
     :param subdomain: Optional subdomain to host OAS on.
     :type subdomain: str or None
     """
     subdomain_arg = subdomain
@@ -344,7 +344,7 @@ def install(clus, args):
     Parses arguments for the 'install' subcommand
 
-    :param cluster.Cluster clus: Cluster object to install OAS to
+    :param cluster.Cluster clus: Cluster object to install Stackspin to
     :param argparse.Namespace args: Command line arguments
     """
@@ -446,7 +446,7 @@ def create_domain_records(domain, droplet_ip, subdomain=None):
     :param str domain: the domain the cluster will be hosted on.
     :param str droplet_ip: The IP address the A record will point to.
-    :param subdomain: Optional subdomain to host OAS on.
+    :param subdomain: Optional subdomain to host Stackspin on.
     :type subdomain: str or None
     """